<?php

/*
  Plugin Name: Tickera sales stats shortcode
  Plugin URI: https://tickera.com
  Description: Adds a custom shortcode tc_sale_stats which shows sales stats on the front-end. Just add shortcode [tc_sale_stats range="1" title="Today's Sales"] or [tc_sale_stats range="30" title="Last 30 days sales"] to the page content
  Author: Tickera
  Author URI: https://tickera.com
  Version: 1.0
  TextDomain: tc
  Domain Path: /languages/

  Copyright 2019 Tickera (https://tickera.com)
 */
if (!defined('ABSPATH')) {
    exit;
} // Exit if accessed directly
if (!class_exists('TC_tickera_sales_stats_shortcode')) {

    class TC_tickera_sales_stats_shortcode {

        public $version = '1.0';
        public $title = 'Tickera sales stats shortcode';
        public $name = 'tickera_sales_stats_shortcode';
        public $dir_name = 'tickera_sales_stats_shortcode';
        public $location = 'plugins';
        public $plugin_dir = '';
        public $plugin_url = '';

        public function __construct() {
            $this->init_vars();

            if (class_exists('TC')) {//Check if Tickera plugin is active / main Tickera class exists
                global $tc;
            }

            add_shortcode('tc_sale_stats', array($this, 'tc_sale_stats'));
        }

        public function init_vars() {
            //setup proper directories
            if (defined('WP_PLUGIN_URL') && defined('WP_PLUGIN_DIR') && file_exists(WP_PLUGIN_DIR . '/' . $this->dir_name . '/' . basename(__FILE__))) {
                $this->location = 'subfolder-plugins';
                $this->plugin_dir = WP_PLUGIN_DIR . '/' . $this->dir_name . '/';
                $this->plugin_url = plugins_url('/', __FILE__);
            } elseif (defined('WP_PLUGIN_URL') && defined('WP_PLUGIN_DIR') && file_exists(WP_PLUGIN_DIR . '/' . basename(__FILE__))) {
                $this->location = 'plugins';
                $this->plugin_dir = WP_PLUGIN_DIR . '/';
                $this->plugin_url = plugins_url('/', __FILE__);
            } elseif (is_multisite() && defined('WPMU_PLUGIN_URL') && defined('WPMU_PLUGIN_DIR') && file_exists(WPMU_PLUGIN_DIR . '/' . basename(__FILE__))) {
                $this->location = 'mu-plugins';
                $this->plugin_dir = WPMU_PLUGIN_DIR;
                $this->plugin_url = WPMU_PLUGIN_URL;
            } else {
                wp_die(sprintf(__('There was an issue determining where %s is installed. Please reinstall it.', 'tc'), $this->title));
            }
        }

        function report($days_range) {
            global $tc, $wpdb;

            $days = $days_range * -1;
            $total_revenue = 0;
            $todays_revenue = 0;
            $count_of_paid_tickets = 0;
            $todays_date = date("Y-m-d");
            $date_30_days_before = date('Y-m-d', strtotime('+' . ($days_range - 1) . ' days'));

            $totals_30 = $wpdb->get_results("SELECT orders.post_date as order_date, order_meta.meta_value FROM wp_posts as orders, wp_postmeta as order_meta WHERE orders.ID = order_meta.post_id AND orders.post_status = 'order_paid' AND order_meta.meta_key = 'tc_payment_info' AND orders.post_date BETWEEN (NOW() - INTERVAL " . $days_range . " DAY) AND (NOW() + INTERVAL 1 DAY)"
            );

            foreach ($totals_30 as $total_record_30_init) {
                $total_record_30 = maybe_unserialize($total_record_30_init->meta_value);
                $total_record_val = isset($total_record_30['total']) ? $total_record_30['total'] : 0;
                $total_revenue = $total_revenue + $total_record_val;
                if (date('Y-m-d', strtotime($total_record_30_init->order_date)) == $todays_date) {
                    $todays_revenue = $todays_revenue + $total_record_val;
                }
                $count_of_paid_tickets++;
            }

            $total_revenue = round($total_revenue, 2);

            $pending_orders_count = (int) $wpdb->get_var($wpdb->prepare("SELECT COUNT(ID) FROM $wpdb->posts WHERE post_type = 'tc_orders' AND post_status = 'order_received' AND post_date BETWEEN %s AND %s", $todays_date, $date_30_days_before));
            $paid_orders_count = (int) $wpdb->get_var($wpdb->prepare("SELECT COUNT(ID) FROM $wpdb->posts WHERE post_type = 'tc_orders' AND post_status = 'order_paid' AND post_date BETWEEN %s AND %s", $todays_date, $date_30_days_before));

            if ($days_range > 1) {
                return $tc->get_cart_currency_and_format($total_revenue);
            } else {
                return $tc->get_cart_currency_and_format($todays_revenue);
            }
        }

        function tc_sale_stats($atts) {
            ob_start();
            extract(shortcode_atts(array(
                'range' => 30,
                'title' => 'Sale Stats: ',
                            )
                            , $atts)
            );

            $value = $this->report($range);

            echo '<div class="tc_sale_stats tc_sale_stats_' . $range . '"><label>' . $title . '</label>' . $value . '</div>';

            $content = ob_get_clean();
            return $content;
        }

    }

}

$TC_tickera_sales_stats_shortcode = new TC_tickera_sales_stats_shortcode();
